##  Strict filtering for filters on relations
Without strict filtering, a Landscape for all applications using the data object “Customer” looks like this:
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio275459217a441014a6bfafd4035da0d7_LowRes.png)
With strict filtering, a Landscape for all applications using the data object “Customer” looks like this:
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio275646b07a441014ab7ce3e5fc9d62a4_LowRes.png)
Similarly, on a matrix report: without strict filtering
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274bc2007a441014b979b5294d81da65_LowRes.png)
With strict filtering
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2757ebaa7a44101487c3d3b5c7490a16_LowRes.png)
